Dag

Struct Dag 

pub struct Dag { /* private fields */ }

Implementations

Source

impl Dag

pub fn builder() -> DagBuilder

Returns a new DAG builder.

pub async fn run(&self, ctx: DagContext) -> Result<DagContext>

Executes the DAG.

Nodes in the same topological level run in parallel. Branch conditions are evaluated after each level to determine which successors are activated for subsequent levels.