pub struct Dag { /* private fields */ }Implementations
Sourceimpl Dag
impl Dag
Sourcepub fn builder() -> DagBuilder
pub fn builder() -> DagBuilder
Returns a new DAG builder.
Sourcepub async fn run(&self, ctx: DagContext) -> Result<DagContext>
pub async fn run(&self, ctx: DagContext) -> Result<DagContext>
Executes the DAG.
Nodes in the same topological level run in parallel. Branch conditions are evaluated after each level to determine which successors are activated for subsequent levels.